ErrorStackDioInterceptor class

Dio interceptor that captures request/response data for the dev panel.

Usage:

final dio = Dio();
dio.interceptors.add(ErrorStackDioInterceptor());

Constructors

ErrorStackDioInterceptor({bool enabled = true, bool filter(RequestOptions options)?})
Creates an ErrorStackDioInterceptor.

Properties

enabled → bool
Whether the interceptor is enabled.
final
filter → bool Function(RequestOptions options)?
Optional filter function to exclude certain requests. Return true to log the request, false to skip it.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited