ErrorStackDebugWidget class

Debug-mode error display widget.

Shows the error message, class name, and stack trace when an error occurs. Provides a Google search link for the error and an option to restart the app.

Inheritance

Constructors

ErrorStackDebugWidget({Key? key, required FlutterErrorDetails errorDetails, String initialRoute = '/', String initialThemeMode = 'light', Future<void> onThemeChanged(String newTheme)?})
const

Properties

errorDetails → FlutterErrorDetails
The error details to display.
final
hashCode → int
The hash code for this object.
no setterinherited
initialRoute → String
The initial route to navigate to when restarting the app.
final
initialThemeMode → String
The initial theme mode ('light' or 'dark').
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onThemeChanged → Future<void> Function(String newTheme)?
Callback invoked when the theme is changed. Receives the new theme mode string.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited