error_stack library
ErrorStack - Custom error handling for Flutter applications.
Provides beautiful error screens in debug mode with actionable information like Google search links and stack traces.
Classes
- ApiRequestLog
- Represents a logged HTTP API request and its response.
- DevPanelConfig
- Configuration for the dev panel.
- DevPanelStore
- Central data store for the dev panel.
- ErrorStack
- The main entry point for ErrorStack.
- ErrorStackConfig
- Configuration options for ErrorStack.
- ErrorStackDevPanel
- ErrorStackDevPanel
- ErrorStackDevPanelSheet
- The main dev panel bottom sheet with tabs.
- ErrorStackHandler
- Handles Flutter errors by logging, parsing stack traces, and building appropriate error widgets.
- A NavigatorObserver that automatically tracks route changes.
- ErrorStackReleaseWidget
- Widget to display a release error stack. This widget is displayed when the app is in release mode. It displays a simple error message.
- ErrorStackStorage
-
Default storage implementation using
FlutterSecureStorage. - ErrorStackStorageBase
- Abstract interface for ErrorStack storage operations.
- LogEntry
- Represents a console log entry.
- RouteEntry
- Represents a navigation route entry in the route history.
- StorageEntry
- Represents a reference to a stored value.
- UIDebugOverlay
- A widget that applies UI debug overlays based on DevPanelStore settings.
Enums
- ColorBlindnessMode
- Color blindness simulation modes.
- DevPanelLogLevel
- Log severity levels for the dev panel console logging.
- ErrorStackLogLevel
- The level of logging to be displayed when an error occurs.
- RouteAction
- The type of navigation action that occurred.
- StorageSource
- The source of stored data.